package be.hub.bookwise.controllers;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import be.hub.bookwise.dao.AccountDAO;
import be.hub.bookwise.domain.Account;

@Controller
public class AccountController {

	@Autowired
	private AccountDAO accountDao;

	@RequestMapping(value = "/accounts.html")
	public String getAllAccounts(Model model) {
		model.addAttribute("accounts", accountDao.getAll());
		// System.out.println(accountDao.getAll());
		return "account.list";

	}

	@RequestMapping(value = "/addAccount.html", method = RequestMethod.GET)
	public String addAccountForm(Model model) {
		model.addAttribute("naccount", new Account());
		return "account.add";
	}

	@RequestMapping(value = "/addAccount.html", method = RequestMethod.POST)
	public String addAccountPost(Model model,
			@ModelAttribute("naccount") @Valid Account newAccount,
			BindingResult result) {
		if (result.hasErrors()) {
			return "account.add";

		} else {
			accountDao.save(newAccount);
			return "redirect:accounts.html";
		}
	}

	@RequestMapping(value = "/account.html", method = RequestMethod.GET)
	public String aboutAccount(Model model, @RequestParam("id") Long id) {
		Account account = accountDao.getById(id);
		model.addAttribute("account", account);
		return "account.edit";

	}

	@RequestMapping(value = "/account.html", method = RequestMethod.POST)
	public String updateAccount(Model model,
			@ModelAttribute("account") @Valid Account account,
			BindingResult result) {
		if (result.hasErrors()) {
			return "account.edit";
		} else {

			accountDao.update(account);
			return "redirect:accounts.html";
		}
	}

}
