package be.hub.bookwise.controllers;

import java.util.Date;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import be.hub.bookwise.dao.*;
import be.hub.bookwise.domain.*;

@Controller
public class OrderController {

	@Autowired
	private ProductDAO productDao;
	@Autowired
	private AccountDAO accountDao;
	@Autowired
	private OrderDAO orderDao;

	@RequestMapping(value = "/orders.html", method = RequestMethod.GET)
	public String getAllOrders(Model model) {
		model.addAttribute("orders", orderDao.getAll());
		return "order.list";

	}

	@RequestMapping(value = "/addOrder.html", method = RequestMethod.GET)
	public String addOrderForm(Model model) {
		Order norder = new Order();
		norder.setDate(new Date());

		model.addAttribute("norder", norder);
		model.addAttribute("accounts", accountDao.getAll());
		model.addAttribute("products", productDao.getAll());
		return "order.add";

	}

	@RequestMapping(value = "/addOrder.html", method = RequestMethod.POST)
	public String addOrder(Model model,
			@ModelAttribute("norder") @Valid Order norder, BindingResult result) {
		if (result.hasErrors()) {
			model.addAttribute("accounts", accountDao.getAll());
			model.addAttribute("products", productDao.getAll());
			return "order.add";
		} else {
			norder = parseFormOrder(norder);
			orderDao.save(norder);
			return "redirect:orders.html";
		}
	}

	@RequestMapping(value = "/order.html", method = RequestMethod.GET)
	public String aboutEditOrder(Model model, @RequestParam("id") Long id) {
		
		model.addAttribute("order", orderDao.getById(id));
		model.addAttribute("accounts", accountDao.getAll());
		model.addAttribute("products", productDao.getAll());
		return "order.edit";
	}

	@RequestMapping(value = "/order.html", method = RequestMethod.POST)
	public String updateOrder(Model model,
			@ModelAttribute("order") @Valid Order order, BindingResult result) {
		if (result.hasErrors()) {
			model.addAttribute("accounts", accountDao.getAll());
			model.addAttribute("products", productDao.getAll());
			return "order.edit";
		} else {
			order = parseFormOrder(order);
			orderDao.update(order);
			return "redirect:orders.html";
		}
	}

	// TODO orders per Account

	/*
	 * De verschillende manieren om een string naar een object te converten
	 * zoals aangegeven op de site van spring werkt niet, daarom houden we
	 * tijdelijk de id als string bij en converteren we deze hier naar een
	 * object via de DAO
	 */
	private Order parseFormOrder(Order order) {
		Long accId = Long.parseLong(order.getFormBenefactor());
		order.setBenefactor(accountDao.getById(accId));
		
		order.setUnit(productDao.getById(order.getFormProduct()));
		order.setBeneficiary(order.getUnit().getSupplier());
		
		return order;
	}
}
