package be.hub.bookwise.controllers;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import be.hub.bookwise.dao.AccountDAO;
import be.hub.bookwise.dao.ProductDAO;
import be.hub.bookwise.domain.Product;

@Controller
public class ProductController {

	@Autowired
	private ProductDAO productDao;
	@Autowired
	private AccountDAO accountDao;

	@RequestMapping(value = "/products.html", method = RequestMethod.GET)
	public String getAllProducts(Model model) {
		// System.out.println("ProductController: coming through");
		// System.out.println(productDao.getAll());
		model.addAttribute("products", productDao.getAll());
		return "product.list";
	}

	@RequestMapping(value = "/addProduct.html", method = RequestMethod.GET)
	public String addProductForm(Model model) {
		model.addAttribute("nproduct", new Product());
		model.addAttribute("accounts", accountDao.getAll());
		return "product.add";
	}

	@RequestMapping(value = "/addProduct.html", method = RequestMethod.POST)
	public String addProduct(Model model,
			@ModelAttribute("nproduct") @Valid Product newProduct,
			BindingResult result) {
		if (result.hasErrors()) {
			return "product.add";
		} else {

			newProduct = parseFormStringObject(newProduct);
			productDao.update(newProduct);
			return "redirect:products.html";
		}
	}

	@RequestMapping(value = "/product.html", method = RequestMethod.GET)
	public String aboutEditProduct(Model model,
			@RequestParam("code") String code) {
		model.addAttribute("product", productDao.getById(code));
		model.addAttribute("accounts", accountDao.getAll());
		return "product.edit";
	}

	@RequestMapping(value = "/product.html", method = RequestMethod.POST)
	public String updateProduct(Model model,
			@ModelAttribute("product") @Valid Product product,
			BindingResult result) {
		if (result.hasErrors()) {
			return "product.edit";
		} else {
			product = parseFormStringObject(product);
			productDao.update(product);
			return "redirect:products.html";
		}
	}

	// TODO products by supplier?
	// TODO get orders by product?
	// TODO nieuw order voor product

	/*
	 * De verschillende manieren om een string naar een object te converten
	 * zoals aangegeven op de site van spring werkt niet, daarom houden we
	 * tijdelijk de id als string bij en converteren we deze hier naar een
	 * object via de DAO
	 */
	private Product parseFormStringObject(Product newProduct) {
		Long accId = Long.parseLong(newProduct.getSupplierFormId());
		newProduct.setSupplier(accountDao.getById(accId));
		return newProduct;
	}

}
